Class: NSIndexSet
- Inherits:
-
Object
- Object
- NSIndexSet
- Includes:
- Enumerable
- Defined in:
- lib/bean/nsindexset_additions.rb
Overview
Extensions to the NSIndexSet class
Instance Method Summary collapse
-
#each {|i| ... } ⇒ nil
Iterate over each of the items in the NSIndexSet.
Instance Method Details
#each {|i| ... } ⇒ nil
Iterate over each of the items in the NSIndexSet
15 16 17 18 19 20 21 |
# File 'lib/bean/nsindexset_additions.rb', line 15 def each i = self.firstIndex until i == NSNotFound yield i i = self.indexGreaterThanIndex(i) end end |